nxp-pac

Crates

git

Versions

lpc55s69_cm33_core0

Flavors

Usbfsh

Struct Usbfsh 

pub struct Usbfsh { /* private fields */ }
USB0 Full-speed Host controller

Implementations

Source

impl Usbfsh

pub const unsafe fn from_ptr(ptr: *mut ()) -> Self

pub const fn as_ptr(&self) -> *mut ()

pub const fn hcrevision(self) -> Reg<Hcrevision, R>

BCD representation of the version of the HCI specification that is implemented by the Host Controller (HC)

pub const fn hccontrol(self) -> Reg<Hccontrol, RW>

Defines the operating modes of the HC

pub const fn hccommandstatus(self) -> Reg<Hccommandstatus, RW>

This register is used to receive the commands from the Host Controller Driver (HCD)

pub const fn hcinterruptstatus(self) -> Reg<Hcinterruptstatus, RW>

Indicates the status on various events that cause hardware interrupts by setting the appropriate bits

pub const fn hcinterruptenable(self) -> Reg<Hcinterruptenable, RW>

Controls the bits in the HcInterruptStatus register and indicates which events will generate a hardware interrupt

pub const fn hcinterruptdisable(self) -> Reg<Hcinterruptdisable, RW>

The bits in this register are used to disable corresponding bits in the HCInterruptStatus register and in turn disable that event leading to hardware interrupt

pub const fn hchcca(self) -> Reg<Hchcca, RW>

Contains the physical address of the host controller communication area

pub const fn hcperiodcurrented(self) -> Reg<Hcperiodcurrented, RW>

Contains the physical address of the current isochronous or interrupt endpoint descriptor

pub const fn hccontrolheaded(self) -> Reg<Hccontrolheaded, RW>

Contains the physical address of the first endpoint descriptor of the control list

pub const fn hccontrolcurrented(self) -> Reg<Hccontrolcurrented, RW>

Contains the physical address of the current endpoint descriptor of the control list

pub const fn hcbulkheaded(self) -> Reg<Hcbulkheaded, RW>

Contains the physical address of the first endpoint descriptor of the bulk list

pub const fn hcbulkcurrented(self) -> Reg<Hcbulkcurrented, RW>

Contains the physical address of the current endpoint descriptor of the bulk list

pub const fn hcdonehead(self) -> Reg<Hcdonehead, RW>

Contains the physical address of the last transfer descriptor added to the ‘Done’ queue

pub const fn hcfminterval(self) -> Reg<Hcfminterval, RW>

Defines the bit time interval in a frame and the full speed maximum packet size which would not cause an overrun

pub const fn hcfmremaining(self) -> Reg<Hcfmremaining, RW>

A 14-bit counter showing the bit time remaining in the current frame

pub const fn hcfmnumber(self) -> Reg<Hcfmnumber, RW>

Contains a 16-bit counter and provides the timing reference among events happening in the HC and the HCD

pub const fn hcperiodicstart(self) -> Reg<Hcperiodicstart, RW>

Contains a programmable 14-bit value which determines the earliest time HC should start processing a periodic list

pub const fn hclsthreshold(self) -> Reg<Hclsthreshold, RW>

Contains 11-bit value which is used by the HC to determine whether to commit to transfer a maximum of 8-byte LS packet before EOF

pub const fn hcrhdescriptora(self) -> Reg<Hcrhdescriptora, RW>

First of the two registers which describes the characteristics of the root hub

pub const fn hcrhdescriptorb(self) -> Reg<Hcrhdescriptorb, RW>

Second of the two registers which describes the characteristics of the Root Hub

pub const fn hcrhstatus(self) -> Reg<Hcrhstatus, RW>

This register is divided into two parts

pub const fn hcrhportstatus(self) -> Reg<Hcrhportstatus, RW>

Controls and reports the port events on a per-port basis

pub const fn portmode(self) -> Reg<Portmode, RW>

Controls the port if it is attached to the host block or the device block